#!/bin/bash
# (C) Copyright 2007-2014 Hewlett Packard Development Company, L.P.
# Version A.12.00.00

# REVISION HISTORY:
#     Version      mm/dd/yyyy   Changes
#     A.04.02.02   10/19/2012   1) Updated the version to A.04.02.02
#                               2) Added code changes to support online toolkit package modification 
#     A.12.0.0     11/29/2013   1) Removed toolkit maintenance mode support
#                               2) Removed Legacy style packaging support
#                               3) Added changes for SG online reconfiguration
#############################################################################
#   LINUX TOMCAT TOOLKIT MODULE SCRIPT                                      #
#############################################################################


###########################
# Source utility functions.
###########################

. /etc/cmcluster.conf
if [[ -z $SG_UTILS ]]
then
    SG_UTILS=$SGCONF/scripts/mscripts/utils.sh
fi

if [[ -f ${SG_UTILS} ]]; then
    . ${SG_UTILS}
    if (( $? != 0 ))
    then
        echo "ERROR: Unable to source package utility functions file: ${SG_UTILS}"
        exit 1
    fi
else
    echo "ERROR: Unable to find package utility functions file: ${SG_UTILS}"
    exit 1
fi

###################################################################
# Get the environment for this package through utility function
# sg_source_pkg_env().
#################################################################################

export PATH=$PATH:$SGSBIN
sg_source_pkg_env $*

#############################
#      START FUNCTION
#############################

function start_function
{
# Checks to see if this is online addition of new module

   if sg_check_if_reconfig_has_failed ; then
      sg_log 999 "WARNING: Not attempting to start the newly added Tomcat toolkit module"
      return 
   fi

   . ${TKIT_SCRIPT_DIR}/toolkit.sh start
   exit_val=$?
   if sg_check_if_it_is_reconfiguration ; then
     if [[  $exit_val -ne 0 ]]; then
       sg_log 999 "ERROR: Failed to start the newly added Tomcat toolkit module"
       sg_set_reconfig_failure
     else
       sg_log 999 "SUCCESS: Successfully started newly added Tomcat toolkit module"
       sg_log 0 "SUCCESS: Successfully started newly added Tomcat toolkit module"
     fi
   fi

}

#############################
#     MONITOR FUNCTION
#############################

function monitor_function
{
    . ${TKIT_SCRIPT_DIR}/toolkit.sh monitor
    exit_val=$?
}

#############################
#     STOP FUNCTION
#############################

function stop_function
{
    . ${TKIT_SCRIPT_DIR}/toolkit.sh stop
    exit_val=$?
}

############################################################
#
# RECONFIGURE STOP FUNCTION
#
############################################################

function reconfigure_stop_function
{
       if sg_check_if_reconfig_has_failed
       then
          sg_log 999 "WARNING: Not attempting to stop the postgresql service $service_name for online package modification."
          return
       fi
       if ! $SGSBIN/cmhaltserv ${service_name} ; then
          sg_log 999 "ERROR: Could not stop  the service $service_name for online package modification."
          sg_set_reconfig_failure 
          exit_code=1
       else
          sg_log 999 "SUCCESS: Successfully stopped  the service $service_name for online package modification."
          sg_log 0 "SUCCESS: Successfully stopped  the service $service_name for online package modification."
       fi
}

#############################################################
#
#       RECONFIGURE START FUNCTION
#
############################################################

function reconfigure_start_function
{
        msg="cmrunserv: Unable to start service $service_name (it is already active)"
        out=`$SGSBIN/cmrunserv $service_name "${service_cmd_string}" 2>&1`
        exit_code=$?
        if [[ $exit_code -ne 0 ]] && [[ "$msg" != "$out" ]] ; then
            sg_log 999 "ERROR: Failed to start the service $service_name after online package modification" 
            sg_set_reconfig_failure
        elif [[ $exit_code -eq 0 ]] ; then
            sg_log 999 "SUCCESS: Successfully started the service $service_name for online package modification."
            if ! sg_check_if_reconfig_has_failed ; then
                 sg_log 0 "SUCCESS: Succesfully started service $service_name for online package modification. "
            fi
        fi
}

############################
#    START OF ROUTINES
############################

typeset -i exit_val=0
export CATALINA_HOME=$TOMCAT_CATALINA_HOME
export CATALINA_BASE=$TOMCAT_CATALINA_BASE
export TOMCAT_USER=$TOMCAT_TOMCAT_USER
export JAVA_HOME=$TOMCAT_JAVA_HOME
export MONITOR_PORT=$TOMCAT_MONITOR_PORT
export MONITOR_INTERVAL=$TOMCAT_MONITOR_INTERVAL
export RETRY_TIMES=$TOMCAT_RETRY_TIMES
export TKIT_SCRIPT_DIR=$SGROOT/tomcattoolkit

#Identify the Toolkit service name and corresponding service command 
if [[ $1 = "reconfigure_stop" || $1 = "reconfigure_start" ]]; then
    if [[ ${#SG_SERVICE_CMD[@]} -ne 0 ]]; then
        i=0
        service_name=""
        service_cmd_string=""
        for cmd in "${SG_SERVICE_CMD[@]}"
        do
            echo "$cmd" | grep "tomcat_monitor" >> /dev/null
            if [[ $? -eq 0 ]]
            then
                service_name=${SG_SERVICE_NAME[$i]}
                service_cmd_string="$cmd"
                break
            fi
            i=$i+1
        done
    fi
fi

case $1 in
   start)
         start_function
         ;;
   stop)
         stop_function
         ;;
   validate)
          : #add validate_function call here
         ;;
   tomcat_monitor)
         monitor_function
         ;;
   reconfigure_stop)
         reconfigure_stop_function
         ;;
   reconfigure_start)
        reconfigure_start_function
        ;;
    *)
         sg_log 0 "Usage: ${0} [ start | stop | tomcat_monitor | validate | reconfigure_stop | reconfigure_start ]"

         ;;
esac
exit $exit_val

