#!/bin/bash
# (C) Copyright 2007-2013 Hewlett Packard Development Company, L.P.
# Version A.12.00.00
##############################################################################
# REVISION HISTORY:
#     Version      mm/dd/yyyy   Changes
#     A.04.02.02   10/19/2012   1) Updated the version to A.04.02.02
#     A.12.0.0     06/06/2013   1) Removed toolkit maintenance mode support
#                               2) Removed Legacy style packaging support
################################################################################

# Script that enables/disables and starts/stops a application Servers for
# SG/LX. (Known as Toolkit Interface Script.)
#
# This script has one parameter passed to it, which then
# will be passed to the HA server main script:
# - start   - to start the application
# - monitor - to monitor the application
# - stop    - to stop the application
#
# This script exit on one of the following code:
#  0: on success
#  1: on fail
#
################################################################################
# Script Program starts from here
################################################################################

#This variable holds the value of the parameter which is passed to this script
ACT=$1

TKIT_SCRIPT_DIR=$SGROOT/tomcattoolkit
HA_SERVER=TOMCAT
HA_SCRIPT="$TKIT_SCRIPT_DIR/hatomcat.sh"

# Function to test the return code
function test_return
{
    if (( $? != 0 ))
    then
        echo "ERROR: $(date '+%b %e %T') - Failed to $ACT $HA_SERVER."
        exit 1
    fi
}


# Function to log a warning message
function log_info
{
    if [[ "$ACT" = "start" ]]
    then
        echo "WARNING: The application script \"$HA_SCRIPT\" does not exist"
        echo -e "\t or is not executable. To run the application server on this node either"
        echo -e "\t install the script to \"$TKIT_SCRIPT_DIR\" directory or use the chmod(1)"
        echo -e "\t command to make the file $HA_SCRIPT an executable. Then restart this package."
    else
        echo "WARNING: The application control script \"$HA_SCRIPT\" does not exist or"
        echo -e "\t is not excutable. Either install the script to \"$TKIT_SCRIPT_DIR\" directory"
        echo -e "\t or use the chmod(1) command to make file $HA_SCRIPT an executable"
        echo -e "\t (You may need to manually clean application resources.)"
    fi

}


# Function to invoke a application toolkit
function invoke_app
{
    if [ -x $HA_SCRIPT ]; then
        . $HA_SCRIPT $ACT
        test_return
    else
        log_info
    fi

    exit 0;
}

# Script entry point; Program starts from here
    invoke_app

